// src/index.ts
import os from "os";
import qr from "qrcode-terminal";
function qrcode(options = {}) {
  return {
    name: "vite-plugin-qrcode",
    apply: "serve",
    configureServer(server) {
      const _listen = server.listen;
      server.listen = function() {
        var _a;
        const isRestart = arguments[1] === true;
        if (!isRestart) {
          (_a = server.httpServer) == null ? void 0 : _a.on("listening", () => {
            setTimeout(() => logQrcode(server, options), 0);
          });
        }
        return _listen.apply(this, arguments);
      };
    }
  };
}
function logQrcode(server, options) {
  const networkUrls = getNetworkUrls(server, options);
  if (networkUrls.length === 0)
    return;
  const info = server.config.logger.info;
  info("  Visit page on mobile:");
  for (const url of networkUrls) {
    qr.generate(url, { small: true }, (result) => {
      info(`  ${cyan(url)}
  ${result.replace(/\n/g, "\n  ")}`);
    });
  }
}
function cyan(str) {
  return `\x1B[36m${str}\x1B[0m`;
}
function getNetworkUrls(server, options) {
  var _a;
  const address = (_a = server.httpServer) == null ? void 0 : _a.address();
  if (!isAddressInfo(address))
    return [];
  const hostname = resolveHostname(server.config.server.host);
  if (hostname.host === "127.0.0.1")
    return [];
  const protocol = server.config.server.https ? "https" : "http";
  const port = address.port;
  const base = server.config.base;
  return Object.values(os.networkInterfaces()).flatMap((nInterface) => nInterface != null ? nInterface : []).filter((detail) => detail && detail.address && detail.family === "IPv4" && !detail.address.includes("127.0.0.1") && (!options.filter || options.filter(detail.address))).map((detail) => `${protocol}://${detail.address}:${port}${base}`);
}
function isAddressInfo(v) {
  return v.address;
}
function resolveHostname(optionsHost) {
  let host;
  if (optionsHost === void 0 || optionsHost === false || optionsHost === "localhost") {
    host = "127.0.0.1";
  } else if (optionsHost === true) {
    host = void 0;
  } else {
    host = optionsHost;
  }
  const name = optionsHost !== "127.0.0.1" && host === "127.0.0.1" || host === "0.0.0.0" || host === "::" || host === void 0 ? "localhost" : host;
  return { host, name };
}
export {
  qrcode
};
